pub struct AvailabilityRecord {
pub start_time: String,
pub end_time: String,
pub recurrence: Option<Box<Recurrence>>,
pub capacity: Option<i32>,
}Expand description
AvailabilityRecord : AvailabilityRecord to represent the capacity of a resource over a time range.
Fields
start_time: StringDenotes the time from when the resource is available in a day in ISO-8601 format.
end_time: StringDenotes the time till when the resource is available in a day in ISO-8601 format.
recurrence: Option<Box<Recurrence>>capacity: Option<i32>Signifies the capacity of a resource which is available.
Implementations
sourceimpl AvailabilityRecord
impl AvailabilityRecord
sourcepub fn new(start_time: String, end_time: String) -> AvailabilityRecord
pub fn new(start_time: String, end_time: String) -> AvailabilityRecord
AvailabilityRecord to represent the capacity of a resource over a time range.